diff --git a/MeshLib/MeshSearch/MeshElementGrid.cpp b/MeshLib/MeshSearch/MeshElementGrid.cpp
index 8e45f5c60fc54f1fa326ab6fc7044abd36ed76f0..0aa33c7554d144958547a50a731861ce8151b4d1 100644
--- a/MeshLib/MeshSearch/MeshElementGrid.cpp
+++ b/MeshLib/MeshSearch/MeshElementGrid.cpp
@@ -21,11 +21,11 @@
 
 #include "GeoLib/GEOObjects.h"
 
-namespace MeshLib {
-
-MeshElementGrid::MeshElementGrid(MeshLib::Mesh const& sfc_mesh) :
-    _aabb{sfc_mesh.getNodes().cbegin(), sfc_mesh.getNodes().cend()},
-    _n_steps({{1,1,1}})
+namespace MeshLib
+{
+MeshElementGrid::MeshElementGrid(MeshLib::Mesh const& mesh)
+    : _aabb{mesh.getNodes().cbegin(), mesh.getNodes().cend()},
+      _n_steps({{1, 1, 1}})
 {
     auto getDimensions =
         [](MathLib::Point3d const& min, MathLib::Point3d const& max)
@@ -49,7 +49,7 @@ MeshElementGrid::MeshElementGrid(MeshLib::Mesh const& sfc_mesh) :
     std::array<double, 3> delta{{ max_pnt[0] - min_pnt[0],
         max_pnt[1] - min_pnt[1], max_pnt[2] - min_pnt[2] }};
 
-    const std::size_t n_eles(sfc_mesh.getNumberOfElements());
+    const std::size_t n_eles(mesh.getNumberOfElements());
     const std::size_t n_eles_per_cell(100);
 
     // *** condition: n_eles / n_cells < n_eles_per_cell
@@ -98,7 +98,7 @@ MeshElementGrid::MeshElementGrid(MeshLib::Mesh const& sfc_mesh) :
     }
 
     _elements_in_grid_box.resize(_n_steps[0]*_n_steps[1]*_n_steps[2]);
-    sortElementsInGridCells(sfc_mesh);
+    sortElementsInGridCells(mesh);
 }
 
 MathLib::Point3d const& MeshElementGrid::getMinPoint() const
@@ -111,9 +111,10 @@ MathLib::Point3d const& MeshElementGrid::getMaxPoint() const
     return _aabb.getMaxPoint();
 }
 
-void MeshElementGrid::sortElementsInGridCells(MeshLib::Mesh const& sfc_mesh)
+void MeshElementGrid::sortElementsInGridCells(MeshLib::Mesh const& mesh)
 {
-    for (auto const element : sfc_mesh.getElements()) {
+    for (auto const element : mesh.getElements())
+    {
         if (! sortElementInGridCells(*element)) {
             OGS_FATAL("Sorting element (id={:d}) into mesh element grid.",
                       element->getID());
diff --git a/MeshLib/MeshSearch/MeshElementGrid.h b/MeshLib/MeshSearch/MeshElementGrid.h
index caae5852840bce90d50641432eb640e438be3bcb..bd546ffee627db920d944a78963c9a250d03b607 100644
--- a/MeshLib/MeshSearch/MeshElementGrid.h
+++ b/MeshLib/MeshSearch/MeshElementGrid.h
@@ -75,7 +75,7 @@ public:
     MathLib::Point3d const& getMaxPoint() const;
 
 private:
-    void sortElementsInGridCells(MeshLib::Mesh const& sfc_mesh);
+    void sortElementsInGridCells(MeshLib::Mesh const& mesh);
     bool sortElementInGridCells(MeshLib::Element const& element);
 
     GeoLib::AABB _aabb;
diff --git a/MeshLib/MeshEditing/Mesh2MeshPropertyInterpolation.h b/MeshLib/MeshEditing/Mesh2MeshPropertyInterpolation.h
index 456ced78ac2008fa1b02315541babb5754d1cbc2..a21574193217575c0e3d54a44c55c7083d44c02e 100644
--- a/MeshLib/MeshEditing/Mesh2MeshPropertyInterpolation.h
+++ b/MeshLib/MeshEditing/Mesh2MeshPropertyInterpolation.h
@@ -41,11 +41,11 @@ public:
     /**
      * Calculates entries for the property vector and sets appropriate indices
      * in the mesh elements.
      * @param mesh the mesh the property information will be calculated and set
      * via weighted interpolation
      * @return true if the operation was successful, false on error
      */
-    bool setPropertiesForMesh(Mesh& mesh) const;
+    bool setPropertiesForMesh(Mesh& dest_mesh) const;
 
 private:
     /**
@@ -41,11 +41,11 @@ public:
      * Calculates entries for the property vector and sets appropriate indices
      * in the mesh elements.
-     * @param mesh the mesh the property information will be calculated and set
-     * via weighted interpolation
+     * @param dest_mesh the mesh the property information will be calculated and
+     * set via weighted interpolation
      * @return true if the operation was successful, false on error
      */